/****************************************************************************
 *              Copyright 2002, Trustees of Boston University.              *
 *                          All Rights Reserved.                            *
 *                                                                          *
 * Author:      Shudong Jin                                                 *
 ****************************************************************************/





/****************************************************************************
 * This file specifies the main configurations of the live streaming media  *
 * access workload generator. The parameters can be modified by the users   *
 * of this software (and it is encouraged). Such modifications should be    *
 * followed by the re-compilation of the source. Many default parameters of *
 * the distributions were obtained through our workload characterization.   *
 ****************************************************************************/




/****************************************************************************
 * The duration of the desirable workload.                                  *
 ****************************************************************************/
#define WORKLOAD_DURATION	(24*60*60) /* one day */



/****************************************************************************
 * Seasonal patterns, flexible, use histogram defined in the file.          *
 * The file contains one number (# of iterations) and a list of numbers.    *
 * This list is then repeated for this # of iterations                      *
 ****************************************************************************/
#define CONFIG_DIURNAL		"config_diurnal"



/****************************************************************************
 * Object popularity index, Zipf                                            *
 ****************************************************************************/
//#define OBJECT_ALPHA	0.73
// This attribute is now specified as an input


/****************************************************************************
 * Client popularity index, Zipf                                            *
 ****************************************************************************/
#define CLIENT_ALPHA	0.4704



/****************************************************************************
 * Number of transfers per session, Pareto                                  *
 ****************************************************************************/
#define TRANSFERS_ALPHA		2.7042



/****************************************************************************
 * Interarrival time of transfers, active OFF time                          *
 ****************************************************************************/
#define TRANSFER_OFF_LOG_MEAN		4.900
#define TRANSFER_OFF_LOG_DERIVATION	1.321



/****************************************************************************
 * Duration of transfers, active ON time                                    *
 ****************************************************************************/
#define TRANSFER_ON_LOG_MEAN		4.384
#define TRANSFER_ON_LOG_DERIVATION	1.427



/****************************************************************************
 * Note, session ON time is derived from transfer (active) ON distribution, *
 * and it is also lognormal. Sesison OFF time is exponential, and it is     *
 * generated by using Poisson session arrivals.                             *
 ****************************************************************************/



/****************************************************************************
 * The bitrate of the objects.                                              *
 * Marginal distribution parameters (Lognormal body / Pareto tail)          *
 ****************************************************************************/
#define VBR_LOG_MEAN		6
#define VBR_LOG_DERIVATION	0.3
#define CUTOFF_SIZE		650
#define Hurst			0.8

/****************************************************************************
 * Number of object attributes to generate.                                 *
 ****************************************************************************/
//#define NUM_ATTRIBUTES          3
// This attribute is now specified as an input
