/****************************************************************************
 *              Copyright 2002, Trustees of Boston University.              *
 *                          All Rights Reserved.                            *
 *                                                                          *
 * Author:      Shudong Jin                                                 *
 ****************************************************************************/


#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include "diurnal.h"



/****************************************************************************
 * This routine generates diurnal access patterns. It is configurated by    *
 * file config_diurnal. This routine reads the histogram in the file, then  *
 * return a session arrival time, such that the arrival rate is consistent  *
 * with the histograms in the config file.                                  *
 ****************************************************************************/

static double	*histo = NULL;
static int	histos;
static int	iterations;
double diurnal_variate(const char *config_diurnal, double y)
{
	int	i, j;
	double	sum1, sum2;

	/*
	 * If it is the first run,
         * read the histo from the file config_diurnal
	 */
	if (histo == NULL) {
		FILE	*fp = fopen(config_diurnal, "r");
		if (fp == NULL) return drand48();

		if (fscanf(fp, "%d\n", &iterations) != 1) {
			fclose(fp);
			return (drand48());
		}

		histo = (double *)malloc(100000 * sizeof(double));
		i = 0;
		while (fscanf(fp, "%lf\n", &histo[i]) == 1) i++;
		fclose(fp);
		assert(100000 > iterations*i);

		for(j = 1; j < iterations; j++) {
			memcpy(histo+j*i,
				histo+(j-1)*i,
				i*sizeof(double));
		}
		histos = i*iterations;
	}

	/*
	 * First compute the sum of histo
	 */
	sum1 = 0.0;
	for(i = 0; i < histos; i++) sum1 += histo[i];
	sum2 = 0.0;
	for(i = 0; i < histos; i++) {
		double l = sum2;
		sum2 += histo[i];
		if (y > sum2/sum1) continue;
		return ((y*sum1-l)/histo[i] + i) / histos;
	}
	return drand48();
}

