/****************************************************************************
 *              Copyright 2002, Trustees of Boston University.              *
 *                          All Rights Reserved.                            *
 *                                                                          *
 * Author:      Shudong Jin                                                 *
 ****************************************************************************/




#include <stdlib.h>
#include <math.h>
#include "lognormal.h"

/****************************************************************************
 * This routine generates Lognormal variate. It is characterized by a scale *
 * parameter "u", and its shape parameter "d". Approximation is used in the *
 * generation of Lognormal variate.                                         *
 ****************************************************************************/

double lognormal_variate(double u, double d)
{
	static double InverseGaussianCDF(double y);

	double y = drand48();
	return exp(u + d*InverseGaussianCDF(y));
}

static double InverseGaussianCDF(double y)
{
	double c0 = 2.515517;
	double c1 = 0.802853;
	double c2 = 0.010328;
	double d1 = 1.432788;
	double d2 = 0.189269;
	double d3 = 0.001308;
	double t, x;

	y = 1 - y;
	if (y <= 0.5) t = sqrt(-2*log(y));
	else t = sqrt(-2*log(1-y));
	x = t - (c0 + c1*t + c2*t*t) / (1 + d1*t + d2*t*t + d3*t*t*t);
	return (y<=0.5 ? x : -x);
}

