/****************************************************************************
 *              Copyright 2001, Trustees of Boston University.              *
 *                          All Rights Reserved.                            *
 *                                                                          *
 * Author:      Shudong Jin                                                 *
 ****************************************************************************/





/****************************************************************************
 * This routine generates frame sizes which exhibit self-similarity and     *
 * follow Gaussian (normal) marginal distribution. Parameter "H" is the     *
 * target Hurst parameter of the self-similarity. Parameters "u" and "d"    *
 * are the mean and derivation of the Gaussian distribution, respectively.  *
 * The routine generates "frames" frame sizes which are returned in vector  *
 * "framesize". No maximum or minimum framesizes are specified.             *
 ****************************************************************************/
void generate_VBR_gaussian(double H, double u, double d,
			int frames, unsigned short framesize[]);


/****************************************************************************
 * This routine generates frame sizes which exhibit self-similarity and     *
 * follow a hybrid Gaussian/Pareto marginal distribution. Parameter "H" is  *
 * the target Hurst parameter for self-similarity. Parameters "u" and "d"   *
 * are the mean and derivation of the Gaussian distribution, respectively.  *
 * Parameter "C" specifies the cut point of the two distributions. The      *
 * parameters of the Pareto distribution is derived by equalizing both the  *
 * value and slope of the two distributions at the cut point.  The routine  *
 * generates "frames" frame sizes which are returned in vector "framesize". *
 * No maximum or minimum framesizes are specified.                          *
 ****************************************************************************/
void generate_VBR_gaussianPareto(double H, double u, double d, double C,
			int frames, unsigned short framesize[]);


/****************************************************************************
 * This routine generates frame sizes which exhibit self-similarity and     *
 * follow a hybrid Lognormal/Pareto marginal distribution. Parameter "H" is *
 * the target Hurst parameter for self-similarity. Parameters "u" and "d"   *
 * are the mean and derivation of the Lognormal distribution, respectively. *
 * Parameter "C" specifies the cut point of the two distributions. The      *
 * parameters of the Pareto distribution is derived by equalizing both the  *
 * value and slope of the two distributions at the cut point.  The routine  *
 * generates "frames" frame sizes which are returned in vector "framesize". *
 * No maximum or minimum framesizes are specified.                          *
 ****************************************************************************/
void generate_VBR_lognormalPareto(double H, double u, double d, double C,
			int frames, unsigned short framesize[]);


/****************************************************************************
 * This routine provides an estimation of the Hurst parameter, given the    *
 * "frames" frame sizes in vector "framesize". The estimation bases on time *
 * -variance plot and uses least-square fit. In order that this routine will*
 * return the result properly, the size of the frame size vector should be  *
 * large enough (>1000 for example).                                        *
 ****************************************************************************/
double HurstEstimation(int frames, const unsigned short framesize[]);

